Built-in identity presets.
Provides 10 realistic browser/device identities that can be retrieved by their numeric ID or selected at random, without any external dependency.
Example
use rustenium_identity::preset;
let id = preset::get_by_id(1).unwrap();
let rnd = preset::random();
println!("{:?}", rnd.browser);