pub struct IdentitySession { /* private fields */ }Expand description
A rustenium browser session with an identity applied.
Implementations
Sourceimpl IdentitySession
impl IdentitySession
Sourcepub async fn launch(
config: impl Into<IdentityConfig>,
) -> Result<Self, IdentityError>
pub async fn launch( config: impl Into<IdentityConfig>, ) -> Result<Self, IdentityError>
Launch a new Chromium instance from the given config. Applies all CDP emulation overrides and registers the stealth bootstrap script before returning.
Sourcepub fn browser(&self) -> &ChromeBrowser
pub fn browser(&self) -> &ChromeBrowser
Access the underlying rustenium ChromeBrowser.
Sourcepub fn browser_mut(&mut self) -> &mut ChromeBrowser
pub fn browser_mut(&mut self) -> &mut ChromeBrowser
Mutable access to the underlying rustenium ChromeBrowser.
pub async fn close(self) -> bool