pub async fn resolve_timezone(
explicit: Option<&str>,
proxy: Option<&str>,
) -> Result<String, IdentityError>Expand description
Resolve timezone: use the explicit override if provided, otherwise query ip-api.com to get the timezone for the proxy IP.